# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litepie/course/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/litepie/course/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Litepie\\Course\\": "packages/litepie/course/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litepie\Course\Providers\CourseServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Course'  => Litepie\Course\Facades\Course::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litepie\\CourseTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litepie\Course\Providers\CourseServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litepie\Course\Providers\CourseServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litepie\Course\Providers\CourseServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/course/{modulename}

**User**

    http://path-to-route-folder/user/course/{modulename}

**Public**

    http://path-to-route-folder/courses


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/course/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/course/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/course/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/course/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/course/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/course/{modulename}/{slug}
    METHOD: GET